# Standard library imports
from datetime import timedelta

# Local imports
#from pyswmm import Simulation
#from pyswmm.tests.data import MODEL_WEIR_SETTING_PATH

###def test_current_time():
##with Simulation(r"C:\KCMOModeling\Model\KCMOMergedModel - Base.inp") as sim:
##
####    start = sim.start_time
####    print(start)
####    endtime = sim.end_time
####    print(endtime)
####    
####    print(start + timedelta(hours = 30))
####    sim.start_time = start + timedelta(hours = 30)
####    sim.end_time = endtime + timedelta(hours = 30)
####    print("\n\n\nDates\n")
##    for step in sim:
##        start = sim.start_time
##        print(start)        
##        #assert (sim.current_time >= sim.start_time)
##        #assert (sim.current_time <= sim.end_time)

from pyswmm import swmm5
sim = swmm5.PySWMM("C:\\PROJECTCODE\\pyswmm\\pyswmm\\tests\\data\\model_pump_setting.inp")
sim.swmm_open()

#sim.SWMMlibobj.swmm_getAPIError()

sim.swmm_close()



import pyswmm
#pyswmm.lib.use("_____REAL___swmm5")


from pyswmm import Simulation


sim = Simulation('OutputTestModel522_SHORT.inp')
print sim.engine_version
print sim.engine_version < sim.engine_version




import os
import sys

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\pyswmm\\')

from ..pyswmm.swmm5 import PySWMM


# this checks the swmmExec process train...

swmmobject = PySWMM('./example/parkinglot.inp',\
                    './example/parkinglot.rpt',\
                    './example/parkinglot.out')

swmmobject.swmmExec()
print(swmmobject.swmm_getVersion())
print(swmmobject.swmm_getMassBalErr())   

print("swmmExec() Check Passed")


#this checks the swmm_step features
swmmobject = PySWMM('./example/parkinglot.inp',\
                    './example/parkinglot.rpt',\
                    './example/parkinglot.out')
swmmobject.swmm_open()
swmmobject.swmm_getSimulationDateTime(0)
swmmobject.swmm_start()

while(True):
    
    time = swmmobject.swmm_step()
##    print time
    if (time <= 0.0):
        break
    
swmmobject.swmm_end()
swmmobject.swmm_report()
swmmobject.swmm_close()

 
print("swmm_step() Check Passed")



'''
PySWMM Test 2: Pump Setting and Simulation Results Streaming

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/15/2016

'''

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.animation as animation
from matplotlib._png import read_png
from matplotlib.offsetbox import OffsetImage, AnnotationBbox


import os
import sys

import random

from pyswmm import Simulation, Links, Nodes


with Simulation('./TestModel3_nodeInflows.inp') as sim:
    sim._model.swmm_start()
    LinkC2 = Links(sim)['C2']
    NodeJ1 = Nodes(sim)['J1']
    

    fig = plt.figure()
    ax = fig.add_subplot(2,3,(1,2))
    ax.set_ylabel('Flow Rate')
    line, = ax.plot([], [], label = 'C3')
    ax.grid()
    ax.legend()

    ax2 = fig.add_subplot(2,3,(4,5), sharex=ax)
    ax2.set_ylabel('Toolkit API\nInflow')
    line2, = ax2.plot([], [], label = 'J1')
    ax2.grid()

    xdata, ydata = [], []
    ydata2 = []

    ax3 = fig.add_subplot(2,3,(3,6))

    arr_lena = read_png("./TestModel3_nodeInflows.PNG")
    imagebox = OffsetImage(arr_lena, zoom=0.67)
    ab = AnnotationBbox(imagebox, (0.5,0.5),
                        xybox=(0.5,0.5),
                        xycoords='data',
                        boxcoords="offset points",
                        pad=0.0,
                        )
    ax3.add_artist(ab)
    ax3.axis('off')
    
    def data_gen(t=0):
        i = 0
        while(True):
            if i >= 10:
                NodeJ1.generated_inflow(random.randint(1,5))
            time = sim._model.swmm_stride(1500)
            i+=1
                
            if i > 0 and time == 0.0:
                break
            if i > 0 and time > 0:
                yield time        
    def run(t):
        
        xdata.append(t)
        new_y = LinkC2.flow
        ydata.append(new_y)
        
        new_y2 = NodeJ1.total_inflow
        ydata2.append(new_y2)
        
        xmin, xmax = ax.get_xlim()
        ymin, ymax = ax.get_ylim()
        ymin2, ymax2 = ax2.get_ylim()

        #ax
        if new_y > ymax:
            ax.set_ylim(-0.1, 1.5*ymax)
        if t >= xmax:
            ax.set_xlim(xmin, 1.5*xmax)
            ax.figure.canvas.draw()
        line.set_data(xdata, ydata)

        #ax1
        if new_y2 > ymax2:
            ax2.set_ylim(-0.1, 1.2*ymax2)
        line2.set_data(xdata, ydata2)    


    ani = animation.FuncAnimation(fig, run, data_gen, blit=False,repeat=False, save_count=300, interval = 5)

    ShowFig = False
    if ShowFig == True:
        plt.show()
    else:
        #ani.save("TestModel3_nodeInflows.mp4", fps=20,dpi=170, bitrate=50000)
        ani.save('SetNodeInflowTest.gif', dpi=200, writer='imagemagick')
    #if 0 == 0:  
    #    from JSAnimation import HTMLWriter
    #    ani.save('LivePlotTest.html', writer=HTMLWriter(embed_frames=False),extra_args=['figsize',[15,6],'dpi',170])

    plt.close()

    sim._model.swmm_end()
    sim._model.swmm_report()
    sim._model.swmm_close()

 
print("Check Passed")



# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) 2014 Bryant E. McDonnell
#
# Licensed under the terms of the BSD2 License
# See LICENSE.txt for details
# -----------------------------------------------------------------------------
"""System module for the pythonic interface to SWMM5."""

# Local imports
from pyswmm.swmm5 import PYSWMMException


class SystemStats(object):
    """
    System-Wide Flow and Runoff Routing Accumulation Volume Methods.

    :param object model: Open Model Instance

    Examples:

    >>> from pyswmm import Simulation, SystemFlowRouting
    >>>
    >>> with Simulation('../test/TestModel1_weirSetting.inp') as sim:
    ...     system_routing = SystemStats(sim)
    ...
    ...     for step in simulation:
    ...         print system_routing.routing_stats
    ...         print system_routing.runoff_stats
    """

    def __init__(self, model):
        if not model._model.fileLoaded:
            raise PYSWMMException("SWMM Model Not Open")
        self._model = model._model

    # --- Get Parameters
    # -------------------------------------------------------------------------
    @property
    def routing_stats(self):
        """
        Get rolling/cumulative routing stats. Follow Data are returned:

        +-------------------------+
        | DWF Inflow Volume       |
        +-------------------------+
        | WWF Inflow Volume       |
        +-------------------------+
        | GW Inflow Volume        |
        +-------------------------+
        | I&I Inflow Volume       |
        +-------------------------+
        | External Inflow Volume  |
        +-------------------------+
        | Flooding Volume         |
        +-------------------------+
        | Outflow Volume          |
        +-------------------------+
        | Evaporation Loss Volume |
        +-------------------------+
        | Seepage Loss Volume     |
        +-------------------------+
        | Routing Error (%)       |
        +-------------------------+

        :return: Statistics
        :rtype: dict
        """
        return self._model.flow_routing_stats()

    @property
    def runoff_stats(self):
        """
        Get rolling/cumulative runoff stats. Follow Data are returned:

        +-----------------------+
        | Total Precipitation   |
        +-----------------------+
        | Evaporation Volume    |
        +-----------------------+
        | Infiltration Volume   |
        +-----------------------+
        | Runoff Volume         |
        +-----------------------+
        | Runon Volume          |
        +-----------------------+
        | Drain Volume          |
        +-----------------------+
        | Snow Removed Volume   |
        +-----------------------+
        | Initial Stored Volume |
        +-----------------------+
        | Initial Snow Volume   |
        +-----------------------+
        | Runoff Routing Error  |
        +-----------------------+

        :return: Statistics
        :rtype: dict
        """
        return self._model.runoff_routing_stats()



import pyswmm
#pyswmm.lib.use("_____REAL___swmm5")


from pyswmm import Simulation, Nodes, Links, Subcatchments

with Simulation('TestModel1_weirSetting.inp') as sim:
    J1 = Nodes(sim)["J1"]
    #flow_route = FlowRouting(sim)
    #runoff_route = RunoffRouting(sim)
    _links = Links(sim)
    
    for link in _links:
        print link.linkid
    for subc in Subcatchments(sim):
        print subc.subcatchmentid

    #print 1/0    
    sim.step_advance(300)
    print(sim.start_time)
    for step in sim:
        J1.generated_inflow(20)
        #print sim.current_time, J1.flooding, runoff_route.rainfall
        #print sim._model.node_statistics("J1", 0)
        #print sim._model.node_statistics("J1", 1)
        #print sim._model.node_statistics("J1", 2)
        #print sim._model.node_statistics("J1", 3)
        #print sim._model.node_statistics("J1", 4)
        
        #print sim._model.link_statistics("C1:C2", 0)
        #print sim._model.link_statistics("C1:C2", 1)
        #print sim._model.link_statistics("C1:C2", 2)

        #print sim._model.subcatch_statistics("S2", 0)
        #print sim._model.subcatch_statistics("S2", 1)

        #print sim._model.system_statistics(0)
        #print sim._model.system_statistics(1)    





'''
TestModel1_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''
import time
import os
import sys
from datetime import datetime, timedelta

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM
from toolkitapi import *



## Test rpt out 
swmmobject = PySWMM('./TestModel1_weirSetting.inp')
swmmobject.swmm_open()
swmmobject.swmmExec()

swmmobject.swmm_close()



## Test Warning
swmmobject = PySWMM('./TestModel1_weirSetting.inp',\
                    './TestModel1_weirSetting.rpt',\
                    './TestModel1_weirSetting.out')
swmmobject.swmm_open()

swmmobject.getLinkResult('C2',0)
swmmobject.swmm_close()

## Test PYSWMMException
swmmobject = PySWMM('./TestModel1_weirSetting.inp',\
                    './TestModel1_weirSetting.rpt',\
                    './TestModel1_weirSetting.out')
swmmobject.swmm_open()
print swmmobject.fileLoaded
swmmobject.swmm_open()
swmmobject.swmm_close()

## Test SWMMException
swmmobject = PySWMM('./TestModel11_weirSetting.inp')
swmmobject.swmm_open()
print swmmobject.fileLoaded
swmmobject.swmm_open()
swmmobject.swmm_close()


print("swmm_step() Check Passed")



'''
TestModel9_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''

#point to location of the pyswmm file
import sys
import os


from pyswmm import Simulation
from pyswmm import Links
from pyswmm import Nodes
# TEST 2
with Simulation('TestModel1_weirSetting.inp') as sim:
    print "\n\n\nLINKS\n"
    c1c2 = Links(sim)["C1:C2"]
    print c1c2.flow

    print c1c2.is_conduit()
    print c1c2.is_pump()
    print c1c2.is_orifice()
    print c1c2.is_weir()
    print c1c2.is_outlet()

    print c1c2.connections
    print c1c2.inlet_node
    print c1c2.outlet_node

    print "\n\n\nNODES\n"
    print c1c2.average_head_loss

    j1 = Nodes(sim)["J1"]
    print j1.is_divider()
    print j1.is_junction()
    print j1.is_outfall()
    print j1.is_storage()
    print j1.invert_elevation
    
    sim.step_advance(300)
    for ind, step in enumerate(sim):
        if c1c2.flow > 9.19:
            c1c2.target_setting = 0.9
    




#import matplotlib.pyplot as plot

import numpy as np


import time

import os
import sys

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM
from toolkitapi import *





swmmobject = PySWMM('./TestModel1_weirSetting.inp',\
                    './TestModel1_weirSetting.rpt',\
                    './TestModel1_weirSetting.out')
swmmobject.swmm_open()

swmmobject.swmm_start()



i = 0
while(True):
    
    time = swmmobject.swmm_stride(600)
    i+=1
    print swmmobject.swmm_getCurrentSimualationTime()
    #print type(swmmobject.swmm_getCurrentSimualationTime())
    fin = swmmobject.swmm_getCurrentSimualationTime()
    if i == 80:
        swmmobject.swmm_setLinkSetting('C3',0.9)
    if i == 90:
        swmmobject.swmm_setLinkSetting('C3',0.8)
    if i == 100:
        swmmobject.swmm_setLinkSetting('C3',0.7)
    if i == 110:
        swmmobject.swmm_setLinkSetting('C3',0.6)
    if i == 120:
        swmmobject.swmm_setLinkSetting('C3',0.5)
    if i == 130:
        swmmobject.swmm_setLinkSetting('C3',0.4)
    if i == 140:
        swmmobject.swmm_setLinkSetting('C3',0.3)
    if i == 150:
        swmmobject.swmm_setLinkSetting('C3',0.2)
    if i == 160:
        swmmobject.swmm_setLinkSetting('C3',0.1)
    if i == 170:
        swmmobject.swmm_setLinkSetting('C3',0.0)          
    if i == 220:
        swmmobject.swmm_setLinkSetting('C3',1.0)        

    if (time <= 0.0):
        break
    if i %144==0: print i
    
swmmobject.swmm_end()
swmmobject.swmm_report()
swmmobject.swmm_close()

 
print("swmm_step() Check Passed")



'''
TestModel1_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''
import time
import os
import sys
from datetime import datetime, timedelta

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM
from toolkitapi import *

swmmobject = PySWMM(r'C:\PROJECTCODE\pyswmm\pyswmm\swmmLinkedLibs\Windows\EmNetSWMM\TestModel1_weirSetting.inp',\
                    r'C:\PROJECTCODE\pyswmm\pyswmm\swmmLinkedLibs\Windows\EmNetSWMM\TestModel1_weirSetting.rpt',\
                    r'C:\PROJECTCODE\pyswmm\pyswmm\swmmLinkedLibs\Windows\EmNetSWMM\TestModel1_weirSetting.out',\
                    r"C:\PROJECTCODE\pyswmm\pyswmm\swmmLinkedLibs\Windows\EmNetSWMM\emnet_swmm5_20170127b.dll")
swmmobject.swmm_open()

print swmmobject.swmm_getNodeParam('J2',NodeParams.invertElev)#, 19 )
swmmobject.swmm_setNodeParam('J2',NodeParams.invertElev, 19 )
print swmmobject.swmm_getNodeParam('J2',NodeParams.invertElev)#, 19 )

print swmmobject.swmm_getLinkParam('C1:C2',LinkParams.offset1)#, 19 )
swmmobject.swmm_setLinkParam('C1:C2',LinkParams.offset1, 19 )
print swmmobject.swmm_getLinkParam('C1:C2',LinkParams.offset1)#, 19 )

print swmmobject.swmm_getSubcatchParam('S2',SubcParams.area)#, 19 )
swmmobject.swmm_setSubcatchParam('S2',SubcParams.area, 19 )
print swmmobject.swmm_getSubcatchParam('S2',SubcParams.area)#, 19 )

swmmobject.swmm_start()

i = 0
while(True):
    
    time = swmmobject.swmm_stride(600)
    i+=1     

    if (time <= 0.0):
        break
    if i %144==0: print i
    swmmobject.swmm_setLinkParam('C1:C2',LinkParams.qLimit, 0.25)
    
swmmobject.swmm_end()
#swmmobject.swmm_report()
swmmobject.swmm_close()

 
print("swmm_step() Check Passed")



'''
TestModel1_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''
import time
import os
import sys

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM
from toolkitapi import *

swmmobject = PySWMM('./TestModel1_weirSetting.inp',\
                    './TestModel1_weirSetting.rpt',\
                    './TestModel1_weirSetting.out')
swmmobject.swmm_open()
print(swmmobject.getSimulationDateTime(0))
swmmobject.swmm_start()

i = 0
while(True):
    
    time = swmmobject.swmm_stride(600)
    i+=1
    print(swmmobject.getCurrentSimulationTime())
    print(type(swmmobject.getCurrentSimulationTime()))
     

    if (time <= 0.0):
        break
    if i %144==0: print(i)
    
swmmobject.swmm_end()
swmmobject.swmm_report()
swmmobject.swmm_close()

 
print("swmm_step() Check Passed")



'''
TestModel9_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''

#point to location of the pyswmm file
import sys
import os
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from pyswmm import Simulation

from random import randint


# TEST 1
sim = Simulation('./TestModel1_weirSetting.inp')

for ind, step in enumerate(sim):
    print(step.getCurrentSimualationTime())
    sim.step_advance( randint(300,900) )
    
sim.report()
sim.close()

# TEST 2
with Simulation('./TestModel1_weirSetting.inp') as sim:
    for ind, step in enumerate(sim):
        sys.stdout.write("\rStatus: "+str(step.getCurrentSimualationTime()))
        sys.stdout.flush()
        
        sim.step_advance( randint(300,900) )

    sim.report()

# TEST 3
sim = Simulation('./TestModel1_weirSetting.inp')        
sim.execute()



from pyswmm import Simulation, Subcatchments, Nodes, Links
from datetime import datetime

#with Simulation('TestModel1_weirSetting.inp') as sim:
with Simulation('model_storage_pump.inp') as sim:
    #sim.start_time = datetime(2011,1,1,0,0,0)
    #sim.end_time = datetime(2011,1,2,0,0,0)

    node = Nodes(sim)["J3"]
    link = Links(sim)["C2"]
    
    sim.step_advance(10)
    for step in sim:
        print sim.current_time
        print(link.conduit_statistics)
        #print(node.cumulative_inflow)
    sim.report()




import pyswmm
#pyswmm.lib.use("_____REAL___swmm5")


from pyswmm import Simulation, FlowRouting, Nodes, RunoffRouting

with Simulation('TestModel1_weirSetting.inp') as sim:
    J1 = Nodes(sim)["J1"]
    flow_route = FlowRouting(sim)
    runoff_route = RunoffRouting(sim)
    
    sim.step_advance(300)
    print(sim.start_time)
    for step in sim:
        J1.generated_inflow(20)
        print sim.current_time, J1.flooding, runoff_route.rainfall

    





# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) 2014 Bryant E. McDonnell
#
# Licensed under the terms of the BSD2 License
# See LICENSE.txt for details
# -----------------------------------------------------------------------------

# Standard library imports
import sys

# Local imports
# from pyswmm import Simulation
# from pyswmm.tests.data import MODEL_WEIR_SETTING_PATH
import pyswmm


def test_use_1():
    if sys.platform == 'darwin':
        pyswmm.lib.use("swmm5.so")
    elif sys.platform.startswith('linux'):
        pyswmm.lib.use("swmm5.so")
    else:
        pyswmm.lib.use("swmm5.dll")


#    sim = Simulation(MODEL_WEIR_SETTING_PATH)


def test_use_2():
    pyswmm.lib.use("swmm5")


#    sim = Simulation(MODEL_WEIR_SETTING_PATH)


def test_use_3():
    try:
        pyswmm.lib.use("fakedll.dll")
    except:
        pass


def test_use_4():
    try:
        pyswmm.lib.use("fakedll")
    except:
        pass



'''
TestModel9_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''

#point to location of the pyswmm file
import sys
import os
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from pyswmm import *
from links import Links
from nodes import Nodes

from random import randint


# TEST 2
with Simulation('TestModel1_weirSetting.inp') as sim:
    c1c2 = Links(sim)["C1:C2"]
    print c1c2.flow
    sim.step_advance(300)
    for ind, step in enumerate(sim):
        print c1c2.flow,c1c2.target_setting
        if c1c2.flow > 9.19:
            c1c2.target_setting = 0.9

    sim.report()



##    
##sim.report()
##sim.close()

#test 3
sim = Simulation('TestModel1_weirSetting.inp')
sim.execute()



'''
TestModel1_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''
import time
import os
import sys

#point to location of the pyswmm file
#sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM, Nodes, Node, Links, Link


swmmobject = PySWMM('./TestModel1_weirSetting.inp')
swmmobject.swmm_open()

for node in Nodes(swmmobject):
    print node
    print node.nodeid
    print node.invertel
    node.invertel = 10
    print node.invertel

node = Node(swmmobject, "J1")
print node.invertel

for link in Links(swmmobject):
    print link
    print link.linkid
    print link.flow_limit
    link.flow_limit =10
    print link.flow_limit

link = Link(swmmobject, "C2")
print link.flow_limit

swmmobject.swmmExec()

swmmobject.swmm_close()

 
print("swmm_step() Check Passed")



'''
TestModel1_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''
import time
import os
import sys
from datetime import datetime, timedelta

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM
from toolkitapi import *

swmmobject = PySWMM('./TestModel1_weirSetting.inp',\
                    './TestModel1_weirSetting.rpt',\
                    './TestModel1_weirSetting.out')
swmmobject.swmm_open()

print swmmobject.getNodeParam('J2',NodeParams.invertElev)#, 19 )
swmmobject.setNodeParam('J2',NodeParams.invertElev, 19 )
print swmmobject.getNodeParam('J2',NodeParams.invertElev)#, 19 )

print swmmobject.getLinkParam('C1:C2',LinkParams.offset1)#, 19 )
swmmobject.setLinkParam('C1:C2',LinkParams.offset1, 19 )
print swmmobject.getLinkParam('C1:C2',LinkParams.offset1)#, 19 )

print swmmobject.getSubcatchParam('S2',SubcParams.area)#, 19 )
swmmobject.setSubcatchParam('S2',SubcParams.area, 19 )
print swmmobject.getSubcatchParam('S2',SubcParams.area)#, 19 )

swmmobject.swmm_start()

i = 0
while(True):
    
    time = swmmobject.swmm_stride(600)
    i+=1     

    if (time <= 0.0):
        break
    if i %144==0: print i
    swmmobject.setLinkParam('C1:C2',LinkParams.qLimit, 0.25)
    
swmmobject.swmm_end()
#swmmobject.swmm_report()
swmmobject.swmm_close()

 
print("swmm_step() Check Passed")



'''
PySWMM Test 2: Pump Setting and Simulation Results Streaming

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/15/2016

'''



import os
import sys

import random

from pyswmm import Simulation, Links, Nodes


with Simulation('./TestModel3_nodeInflows.inp') as sim:
    LinkC2 = Links(sim)['C2']
    NodeJ1 = Nodes(sim)['J1']
    
    for ind, step in enumerate(sim):
        print sim.current_time
        if ind > 15:
            NodeJ1.generated_inflow(10)
        #print ind, LinkC2.flow, NodeJ1.total_inflow

    
   



'''
TestModel1_Current Time

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/12/2016


'''
import time
import os
import sys
from datetime import datetime, timedelta

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM
from toolkitapi import *

swmmobject = PySWMM('./TestModel1_weirSetting.inp',\
                    './TestModel1_weirSetting.rpt',\
                    './TestModel1_weirSetting.out')
swmmobject.swmm_open()

print swmmobject.getSimulationDateTime(0)
print swmmobject.getSimulationDateTime(0) - timedelta(days = 10)
swmmobject.setSimulationDateTime(0, swmmobject.getSimulationDateTime(0) - timedelta(days = 10))
print swmmobject.getSimulationDateTime(0)

print swmmobject.getSimulationDateTime(1)
print swmmobject.getSimulationDateTime(1) - timedelta(days = 10)
swmmobject.setSimulationDateTime(1, swmmobject.getSimulationDateTime(1) - timedelta(days = 10))
print swmmobject.getSimulationDateTime(1)

print swmmobject.getSimulationDateTime(2)
print swmmobject.getSimulationDateTime(2) - timedelta(days = 10)
swmmobject.setSimulationDateTime(2, swmmobject.getSimulationDateTime(2) - timedelta(days = 10))
print swmmobject.getSimulationDateTime(2)


swmmobject.swmm_start()

i = 0
while(True):
    
    time = swmmobject.swmm_stride(600)
    i+=1
    print(swmmobject.getCurrentSimualationTime())
    print(type(swmmobject.getCurrentSimualationTime()))
     

    if (time <= 0.0):
        break
    if i %144==0: print i
    
swmmobject.swmm_end()
#swmmobject.swmm_report()
swmmobject.swmm_close()

 
print("swmm_step() Check Passed")



'''
PySWMM Test 2: Pump Setting and Simulation Results Streaming

Author: Bryant E. McDonnell (EmNet LLC)
Date: 11/15/2016

'''

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.animation as animation
from matplotlib._png import read_png
from matplotlib.offsetbox import OffsetImage, AnnotationBbox


import os
import sys

#point to location of the pyswmm file
sys.path.append(os.getcwd()+'\\..\\pyswmm\\')

from swmm5 import PySWMM
from toolkitapi import *



swmmobject = PySWMM('./TestModel2_pumpSetting.inp',\
                    './TestModel2_pumpSetting.rpt',\
                    './TestModel2_pumpSetting.out')
swmmobject.swmm_open()

swmmobject.swmm_start()

fig = plt.figure()
ax = fig.add_subplot(2,3,(1,2))
ax.set_ylabel('Flow Rate')
line, = ax.plot([], [], label = 'C3')
ax.grid()
ax.legend()

ax2 = fig.add_subplot(2,3,(4,5), sharex=ax)
ax2.set_ylabel('Setting')
line2, = ax2.plot([], [], label = 'C3')
ax2.grid()

xdata, ydata = [], []
ydata2 = []

ax3 = fig.add_subplot(2,3,(3,6))

arr_lena = read_png("./TestModel1_weirSetting.PNG")
imagebox = OffsetImage(arr_lena, zoom=0.67)
ab = AnnotationBbox(imagebox, (0.5,0.5),
                    xybox=(0.5,0.5),
                    xycoords='data',
                    boxcoords="offset points",
                    pad=0.0,
                    )
ax3.add_artist(ab)
ax3.axis('off')

def data_gen(t=0):
    i = 0
    while(True):

        time = swmmobject.swmm_stride(300)
        i+=1
        if i == 80:
            swmmobject.setLinkSetting('C3',0.9)
        if i == 90:
            swmmobject.setLinkSetting('C3',0.8)
        if i == 100:
            swmmobject.setLinkSetting('C3',0.7)
        if i == 110:
            swmmobject.setLinkSetting('C3',0.6)
        if i == 120:
            swmmobject.setLinkSetting('C3',2.0)
        if i == 130:
            swmmobject.setLinkSetting('C3',0.4)
        if i == 140:
            swmmobject.setLinkSetting('C3',0.3)
        if i == 150:
            swmmobject.setLinkSetting('C3',0.2)
        if i == 160:
            swmmobject.setLinkSetting('C3',0.1)
        if i == 170:
            swmmobject.setLinkSetting('C3',0.0)          
        if i == 220:
            swmmobject.setLinkSetting('C3',1.0)
            
        if i > 0 and time == 0.0:
            break
        if i > 0 and time > 0:
            yield time        
def run(t):
    
    xdata.append(t)
    new_y = swmmobject.getLinkResult('C3',LinkResults.newFlow.value)
    ydata.append(new_y)
    
    new_y2 = swmmobject.getLinkResult('C3',LinkResults.setting.value)
    ydata2.append(new_y2)
    
    xmin, xmax = ax.get_xlim()
    ymin, ymax = ax.get_ylim()
    ymin2, ymax2 = ax2.get_ylim()

    #ax
    if new_y > ymax:
        ax.set_ylim(-0.1, 1.5*ymax)
    if t >= xmax:
        ax.set_xlim(xmin, 1.5*xmax)
        ax.figure.canvas.draw()
    line.set_data(xdata, ydata)

    #ax1
    if new_y2 > ymax2:
        ax2.set_ylim(-0.1, 1.2*ymax2)
    line2.set_data(xdata, ydata2)    


ani = animation.FuncAnimation(fig, run, data_gen, blit=False,repeat=False, save_count=800, interval = 10)

ShowFig = False
if ShowFig == True:
    plt.show()
else:
    ani.save("TestModel2_pumpSetting.mp4", fps=20,dpi=170, bitrate=50000)
    
#if 0 == 0:  
#    from JSAnimation import HTMLWriter
#    ani.save('LivePlotTest.html', writer=HTMLWriter(embed_frames=False),extra_args=['figsize',[15,6],'dpi',170])

plt.close()

swmmobject.swmm_end()
swmmobject.swmm_report()
swmmobject.swmm_close()

 
print("Check Passed")
